/** \file DataView.h
    \brief Declaration of DataView class.
    \author James Peachey

    The Profit software package was developed by Dr. Randall Smith and
    Mr. James Peachey at the High Energy Astrophysics Science Archive
    Research Center (HEASARC) at the Goddard Space Flight Center (GSFC)
    of the National Aeronautics and Space Administration (NASA).
*/
#ifndef profit_DataView_h
#define profit_DataView_h

#include <set>

namespace profit {

  class Datum;

  /** \class DataView
      \brief Class encapsulating the concept of a view of one or more Datum objects.
  */
  class DataView {
    public:
      typedef std::set<const Datum *> const_data_cont_type;

      virtual ~DataView();

      /** \brief Perform view-specific updates based on the given container of data.

          Note this does not preclude other data from also being used in the update.
          \param data_cont Container of data which changed recently, and may affect this view.
      */
      virtual void update(const const_data_cont_type & data_cont) = 0;
  };

}

#endif
